@@ -88,7 +88,7 @@ public:
 // user defined declarations:
 public:
 
-# 156 "/build/kdevelop-php/src/kdev-php-5.3.2/parser/php.g" 1
+# 156 "/build/kdevelop-php/src/kdev-php-5.4.6/parser/php.g" 1
 
     /**
      * Transform the raw input into tokens.
@@ -124,7 +124,7 @@ public:
 
 private:
 
-# 188 "/build/kdevelop-php/src/kdev-php-5.3.2/parser/php.g" 1
+# 188 "/build/kdevelop-php/src/kdev-php-5.4.6/parser/php.g" 1
 
     enum VarExpressionState
     {
@@ -162,14 +162,14 @@ public:
     void restoreState(ParserState *state);
     Parser()
     {
-        memoryPool = 0;
-        tokenStream = 0;
+        memoryPool = nullptr;
+        tokenStream = nullptr;
         yytoken = Token_EOF;
         mBlockErrors = false;
 
 // user defined constructor code:
 
-# 209 "/build/kdevelop-php/src/kdev-php-5.3.2/parser/php.g" 1
+# 209 "/build/kdevelop-php/src/kdev-php-5.4.6/parser/php.g" 1
 
         m_state.varExpressionState = Normal;
         m_state.varExpressionIsVariable = false;
